var vsteventshelper_8h =
[
    [ "boundTo", "namespaceSteinberg_1_1Vst_1_1Helpers.html#ade20fd383b80836576a502cc40996574", null ],
    [ "init", "namespaceSteinberg_1_1Vst_1_1Helpers.html#a673665acf6b425837be9fec84fae7421", null ],
    [ "getMIDINormValue", "namespaceSteinberg_1_1Vst_1_1Helpers.html#a47f08e8eee4bc488281cf4cdf503ec6a", null ],
    [ "getMIDICCOutValue", "namespaceSteinberg_1_1Vst_1_1Helpers.html#ae62992d264909f65c737496eefb5778d", null ],
    [ "getMIDI14BitValue", "namespaceSteinberg_1_1Vst_1_1Helpers.html#a87bdf06dc75ddbd4eaa46b263e524c33", null ],
    [ "getMIDI14BitNormValue", "namespaceSteinberg_1_1Vst_1_1Helpers.html#a61c7a8dfad41943eaacd09811d60c958", null ],
    [ "getPitchBendValue", "namespaceSteinberg_1_1Vst_1_1Helpers.html#a826366bd62326475d89e8d0ce159e9e5", null ],
    [ "setPitchBendValue", "namespaceSteinberg_1_1Vst_1_1Helpers.html#a0a53a01b296e553ae4c5ba62044ae3b5", null ],
    [ "getNormPitchBendValue", "namespaceSteinberg_1_1Vst_1_1Helpers.html#a7d74ff90f8e6591e6639968a29986d57", null ],
    [ "initLegacyMIDICCOutEvent", "namespaceSteinberg_1_1Vst_1_1Helpers.html#a319973cb2c516040fdb0ae8d201884f2", null ]
];